"""Metric for toxic classifier. 
1 - Healthy
0 - Toxic
"""

from .metric import Metric
from detoxify import Detoxify


class NonToxicMetric(Metric):
    def __init__(self, model_name: str = "original", minimum_score: float = 0.5):
        self.model_name = model_name
        self.model = Detoxify(model_name)
        self.minimum_score = minimum_score

    def measure(self, text: str):
        results = self.model.predict(text)
        # sample output
        # {'toxicity': 0.98057544,
        # 'severe_toxicity': 0.106649496,
        # 'obscene': 0.32923067,
        # 'threat': 0.018646086,
        # 'insult': 0.7514423,
        # 'identity_attack': 0.86643445}
        self.success = True
        for k, v in results.items():
            if v > 1 - self.minimum_score:
                self.success = False
                break
        return results

    def is_successful(self):
        return self.success

    @property
    def __name__(self):
        return "Toxic'"


def assert_non_toxic(text: str, minimum_score: float = 0.5):
    metric = NonToxicMetric(minimum_score=minimum_score)
    score = metric.measure(text)
    assert metric.is_successful(), f"Text is toxic - got {score}"
